@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Extras::Karma;
-$Bot::Cobalt::Plugin::Extras::Karma::VERSION = '0.019001';
+$Bot::Cobalt::Plugin::Extras::Karma::VERSION = '0.019002';
 ## simple karma++/-- tracking
 
 use Carp;
@@ -116,9 +116,9 @@ sub Bot_karmaplug_sync_db {
 sub Bot_public_msg {
   my ($self, $core) = splice @_, 0, 2;
   my $msg     = ${$_[0]};
-  my $context = $msg->context;
   return PLUGIN_EAT_NONE if $msg->highlight
                          or $msg->cmd;
+  my $context = $msg->context;
 
   my $first_word = $msg->message_array->[0] // return PLUGIN_EAT_NONE;
   $first_word = decode_irc($first_word);
@@ -222,12 +222,12 @@ sub Bot_public_cmd_topkarma {
                 ->sliced( ($sorted->end - 4) .. $sorted->end )
                 ->grep(sub { defined });
 
-  my $str = '[top: ';
+  my $str = '[ top -> ';
   for my $pair ($top->reverse->all) {
     my ($item, $karma) = @$pair;
     $str .= "'${item}':${karma} ";
   }
-  $str .= ']; [bottom: ';
+  $str .= ']; [ bottom -> ';
   for my $pair ($bottom->all) {
     my ($item, $karma) = @$pair;
     $str .= "'${item}':${karma} ";
